@@ -3,34 +3,35 @@
 <TS version="2.0" language="el">
 <context>
     <name>DecoderMPG123Factory</name>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="111"/>
-        <source>MPG123 Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../decodermpg123factory.cpp" line="114"/>
+        <source>MPG123 Plugin</source>
+        <translation>Πρόσθετο MPG123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="117"/>
         <source>MPEG Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Αρχεία MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="267"/>
+        <location filename="../decodermpg123factory.cpp" line="270"/>
         <source>About MPG123 Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="268"/>
-        <source>Qmmp MPG123 Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="269"/>
-        <source>This plugin provides MPEG v1/2 layer1/2/3 support
-with use of libmpg123 library</source>
-        <translation type="unfinished"></translation>
+        <translation>Περί του πρόσθετου ήχου MPG123</translation>
     </message>
     <message>
         <location filename="../decodermpg123factory.cpp" line="271"/>
+        <source>Qmmp MPG123 Audio Plugin</source>
+        <translation>Qmmp πρόσθετο ήχου MPG123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="272"/>
+        <source>This plugin provides MPEG v1/2 layer1/2/3 support
+with use of libmpg123 library</source>
+        <translation>Αυτό το πρόσθετο παρέχει υποστήριξη MPEG v1/2 layer 1/2/3
+με χρήση της βιβλιοθήκης libmpg123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="274"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -40,27 +41,27 @@ with use of libmpg123 library</source>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="70"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Μορφή</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>Bitrate</source>
-        <translation type="unfinished"></translation>
+        <translation>Ρυθμός bit</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>kbps</source>
-        <translation type="unfinished"></translation>
+        <translation>kbps</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Sample rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Ρυθμός δειγματοληψίας</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Hz</source>
-        <translation type="unfinished"></translation>
+        <translation>Hz</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="78"/>
@@ -68,49 +69,49 @@ with use of libmpg123 library</source>
         <location filename="../mpegmetadatamodel.cpp" line="84"/>
         <location filename="../mpegmetadatamodel.cpp" line="87"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Λειτουργία</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="90"/>
         <source>KB</source>
-        <translation type="unfinished"></translation>
+        <translation>KB</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="91"/>
         <source>File size</source>
-        <translation type="unfinished"></translation>
+        <translation>Μέγεθος αρχείου</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <source>Protection</source>
-        <translation type="unfinished"></translation>
+        <translation>Προστασία</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Ναι</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Όχι</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <source>Copyright</source>
-        <translation type="unfinished"></translation>
+        <translation>Πνευματικά δικαιώματα</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>Original</source>
-        <translation type="unfinished"></translation>
+        <translation>Αρχικό</translation>
     </message>
 </context>
 <context>
@@ -118,70 +119,70 @@ with use of libmpg123 library</source>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>MPEG Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ρυθμίσεις πρόσθετου MPEG</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
         <source>Tag Priority</source>
-        <translation type="unfinished"></translation>
+        <translation>Προτεραιότητα ετικέτας</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
         <source>First:</source>
-        <translation type="unfinished"></translation>
+        <translation>Πρώτη:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="61"/>
         <location filename="../settingsdialog.ui" line="110"/>
         <location filename="../settingsdialog.ui" line="159"/>
         <source>ID3v1</source>
-        <translation type="unfinished"></translation>
+        <translation>ID3v1</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="66"/>
         <location filename="../settingsdialog.ui" line="115"/>
         <location filename="../settingsdialog.ui" line="164"/>
         <source>ID3v2</source>
-        <translation type="unfinished"></translation>
+        <translation>ID3v2</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="71"/>
         <location filename="../settingsdialog.ui" line="120"/>
         <location filename="../settingsdialog.ui" line="169"/>
         <source>APE</source>
-        <translation type="unfinished"></translation>
+        <translation>APE</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="76"/>
         <location filename="../settingsdialog.ui" line="125"/>
         <location filename="../settingsdialog.ui" line="174"/>
         <source>Disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Απενεργοποιημένο</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="90"/>
         <source>Second:</source>
-        <translation type="unfinished"></translation>
+        <translation>Δεύτερη:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="139"/>
         <source>Third:</source>
-        <translation type="unfinished"></translation>
+        <translation>Τρίτη:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="198"/>
         <source>Encodings</source>
-        <translation type="unfinished"></translation>
+        <translation>Κωδικοποιήσεις</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="210"/>
         <source>ID3v1 encoding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Κωδικοποίηση ID3v1:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="236"/>
         <source>ID3v2 encoding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Κωδικοποίηση ID3v2:</translation>
     </message>
 </context>
 </TS>
