@@ -3,36 +3,37 @@
 <TS version="2.0" language="gl_ES">
 <context>
     <name>DecoderMPG123Factory</name>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="111"/>
-        <source>MPG123 Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../decodermpg123factory.cpp" line="114"/>
+        <source>MPG123 Plugin</source>
+        <translation>Plugin MPG123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="117"/>
         <source>MPEG Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Ficheiros MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="267"/>
+        <location filename="../decodermpg123factory.cpp" line="270"/>
         <source>About MPG123 Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="268"/>
-        <source>Qmmp MPG123 Audio Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decodermpg123factory.cpp" line="269"/>
-        <source>This plugin provides MPEG v1/2 layer1/2/3 support
-with use of libmpg123 library</source>
-        <translation type="unfinished"></translation>
+        <translation>Acerca do plugin de audio MPG123</translation>
     </message>
     <message>
         <location filename="../decodermpg123factory.cpp" line="271"/>
+        <source>Qmmp MPG123 Audio Plugin</source>
+        <translation>Plugin de audio Qmmp MPG123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="272"/>
+        <source>This plugin provides MPEG v1/2 layer1/2/3 support
+with use of libmpg123 library</source>
+        <translation>Este plugin fornece soporte para o uso de MPEG v1/2 capas1/2/3
+no uso da biblioteca libmpg123</translation>
+    </message>
+    <message>
+        <location filename="../decodermpg123factory.cpp" line="274"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
@@ -40,27 +41,27 @@ with use of libmpg123 library</source>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="70"/>
         <source>Format</source>
-        <translation type="unfinished"></translation>
+        <translation>Formato</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>Bitrate</source>
-        <translation type="unfinished"></translation>
+        <translation>Taxa de bits</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="72"/>
         <source>kbps</source>
-        <translation type="unfinished"></translation>
+        <translation>kbps</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Sample rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Frecuencia de mostra</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="74"/>
         <source>Hz</source>
-        <translation type="unfinished"></translation>
+        <translation>Hz</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="78"/>
@@ -68,49 +69,49 @@ with use of libmpg123 library</source>
         <location filename="../mpegmetadatamodel.cpp" line="84"/>
         <location filename="../mpegmetadatamodel.cpp" line="87"/>
         <source>Mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Modo</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="90"/>
         <source>KB</source>
-        <translation type="unfinished"></translation>
+        <translation>KB</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="91"/>
         <source>File size</source>
-        <translation type="unfinished"></translation>
+        <translation>Tamaño do ficheiro</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <source>Protection</source>
-        <translation type="unfinished"></translation>
+        <translation>Protección</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="93"/>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Si</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="95"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Non</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="97"/>
         <location filename="../mpegmetadatamodel.cpp" line="99"/>
         <source>Copyright</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="101"/>
         <location filename="../mpegmetadatamodel.cpp" line="103"/>
         <source>Original</source>
-        <translation type="unfinished"></translation>
+        <translation>Orixinal</translation>
     </message>
 </context>
 <context>
@@ -118,70 +119,70 @@ with use of libmpg123 library</source>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>MPEG Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Preferencias do engadido MPEG</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
         <source>Tag Priority</source>
-        <translation type="unfinished"></translation>
+        <translation>Prioridade de etiquetas</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="41"/>
         <source>First:</source>
-        <translation type="unfinished"></translation>
+        <translation>Primeira:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="61"/>
         <location filename="../settingsdialog.ui" line="110"/>
         <location filename="../settingsdialog.ui" line="159"/>
         <source>ID3v1</source>
-        <translation type="unfinished"></translation>
+        <translation>ID3v1</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="66"/>
         <location filename="../settingsdialog.ui" line="115"/>
         <location filename="../settingsdialog.ui" line="164"/>
         <source>ID3v2</source>
-        <translation type="unfinished"></translation>
+        <translation>ID3v2</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="71"/>
         <location filename="../settingsdialog.ui" line="120"/>
         <location filename="../settingsdialog.ui" line="169"/>
         <source>APE</source>
-        <translation type="unfinished"></translation>
+        <translation>APE</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="76"/>
         <location filename="../settingsdialog.ui" line="125"/>
         <location filename="../settingsdialog.ui" line="174"/>
         <source>Disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactivado</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="90"/>
         <source>Second:</source>
-        <translation type="unfinished"></translation>
+        <translation>Segunda:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="139"/>
         <source>Third:</source>
-        <translation type="unfinished"></translation>
+        <translation>Terceira:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="198"/>
         <source>Encodings</source>
-        <translation type="unfinished"></translation>
+        <translation>Codificacións</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="210"/>
         <source>ID3v1 encoding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Codificación ID3v1:</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="236"/>
         <source>ID3v2 encoding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Codificación ID3v2:</translation>
     </message>
 </context>
 </TS>
