@@ -4,27 +4,27 @@
 <context>
     <name>DecoderMPG123Factory</name>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="111"/>
+        <location filename="../decodermpg123factory.cpp" line="114"/>
         <source>MPG123 Plugin</source>
         <translation>Модуль MPG123</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="114"/>
+        <location filename="../decodermpg123factory.cpp" line="117"/>
         <source>MPEG Files</source>
         <translation>Файлы MPEG</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="267"/>
+        <location filename="../decodermpg123factory.cpp" line="270"/>
         <source>About MPG123 Audio Plugin</source>
         <translation>О модуле MPG123</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="268"/>
+        <location filename="../decodermpg123factory.cpp" line="271"/>
         <source>Qmmp MPG123 Audio Plugin</source>
         <translation>Модуль MPG123 для Qmmp</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="269"/>
+        <location filename="../decodermpg123factory.cpp" line="272"/>
         <source>This plugin provides MPEG v1/2 layer1/2/3 support
 with use of libmpg123 library</source>
         <translation>Этот модуль предоставляет поддержку
@@ -32,7 +32,7 @@ MPEG v1/2 layer1/2/3 с использованием библиотеки
 libmpg123</translation>
     </message>
     <message>
-        <location filename="../decodermpg123factory.cpp" line="271"/>
+        <location filename="../decodermpg123factory.cpp" line="274"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -75,7 +75,7 @@ libmpg123</translation>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="90"/>
         <source>KB</source>
-        <translation>КБ</translation>
+        <translation>кбит/с</translation>
     </message>
     <message>
         <location filename="../mpegmetadatamodel.cpp" line="91"/>
